@@ -533,7 +533,7 @@ class PrebufferStateFalse(BasePrebufferState):
     state: bool
 
 
-PrebufferConfig = Union[PrebufferStateTrue, PrebufferStateFalse]
+PrebufferState = Union[PrebufferStateTrue, PrebufferStateFalse]
 
 PrebufferContainer = Literal["mpegts", "mp4"]
 
@@ -575,10 +575,10 @@ class CameraSource(Protocol):
     # end
 
     async def update_prebuffering_state(
-        self, container: PrebufferContainer, state: PrebufferConfig
+        self, container: PrebufferContainer, state: PrebufferState
     ) -> None: ...
-    def get_prebuffering_state(self, container: PrebufferContainer) -> PrebufferConfig: ...
-    def on_prebuffering(self, container: PrebufferContainer) -> Observable[PrebufferConfig]: ...
+    def get_prebuffering_state(self, container: PrebufferContainer) -> PrebufferState: ...
+    def on_prebuffering(self, container: PrebufferContainer) -> Observable[PrebufferState]: ...
     async def get_stream_info(self) -> Optional[StreamInfo]: ...
 
 
